Module encode

Module encode 

Module that implements the RLNC encoding algorithm.

Structs

Encoder
RLNC encoder that’s generic over the Field type. An ancoder should be instantiated per piece of data the caller wants to encode, then used to generate the encoded chunks.