pub struct PedersenCommitter { /* private fields */ }Expand description
A committer that uses the non-hiding Pedersen commitment scheme.
Idea
Pedersen commitments work with a number of generators, which are pre-computed and stored in the committer. The commitment is computed as the sum of the generators multiplied by the symbols.
Since we don’t want to transmit the generators to the verifier, we use deterministic generators, which can be derived from a seed (like a sender’s public key).
Security
The security of the Pedersen commitment scheme relies on the discrete logarithm assumption. The generators are chosen such that the discrete logarithm of the commitment to a symbol is hard to compute.
Implementations