pub struct Encoder<F: Field> { /* private fields */ }Expand description
RLNC encoder that’s generic over the Field type. An ancoder should be instantiated
per piece of data the caller wants to encode, then used to generate the encoded chunks.
Implementations
Sourceimpl<F: Field> Encoder<F>
impl<F: Field> Encoder<F>
Sourcepub fn new(
data: impl AsRef<[u8]>,
chunk_count: usize,
) -> Result<Self, RLNCError>
pub fn new( data: impl AsRef<[u8]>, chunk_count: usize, ) -> Result<Self, RLNCError>
Creates a new encoder for the given data and chunk count.
Sourcepub fn from_chunks(chunks: Chunks<F>) -> Self
pub fn from_chunks(chunks: Chunks<F>) -> Self
Creates a new encoder from a vector of chunks.
Sourcepub fn chunk_count(&self) -> usize
pub fn chunk_count(&self) -> usize
Returns the number of chunks in the encoder.
Sourcepub fn chunk_size(&self) -> usize
pub fn chunk_size(&self) -> usize
Returns the size of each chunk in the encoder.
Sourcepub fn prepare(
data: impl AsRef<[u8]>,
chunk_count: usize,
) -> Result<Chunks<F>, RLNCError>
pub fn prepare( data: impl AsRef<[u8]>, chunk_count: usize, ) -> Result<Chunks<F>, RLNCError>
Prepares the data for encoding by splitting it into equally sized chunks and padding with zeros. Also converts the data into symbols in the chosen finite field.
Sourcepub fn encode_with_vector(
&self,
coding_vector: &[F],
) -> Result<RLNCPacket<F>, RLNCError>
pub fn encode_with_vector( &self, coding_vector: &[F], ) -> Result<RLNCPacket<F>, RLNCError>
Encodes the data with the given coding vector using linear combinations.
This method computes a coded packet by taking a linear combination of all chunks using the coefficients from the coding vector. The operation is performed in the field of BLS12-381.
Mathematical Representation
Given original chunks X₁, X₂, …, Xₖ and coding vector coefficients c₁, c₂, …, cₖ, the coded packet Y is computed as:
Y = c₁ ⊗ X₁ ⊕ c₂ ⊗ X₂ ⊕ ... ⊕ cₖ ⊗ XₖWhere:
- ⊗ denotes multiplication in the field of BLS12-381
- ⊕ denotes addition in the field of BLS12-381
- k is the chunk count (generation size)
Each byte position j in the coded packet is computed as:
Y[j] = Σᵢ₌₁ᵏ (cᵢ ⊗ Xᵢ[j]) (mod p)Algorithm Complexity
O(k * n) where k is the chunk count and n is the chunk size.
Sourcepub fn encode<R: Rng>(&self, rng: R) -> Result<RLNCPacket<F>, RLNCError>
pub fn encode<R: Rng>(&self, rng: R) -> Result<RLNCPacket<F>, RLNCError>
Encodes the data with a random coding vector, using the provided random number generator.